require 'mina/dotenv/utils'
require 'mina/scp'

namespace :dotenv do
  desc 'Copies the local .env file to the server'
  task :push do
    dotenv = Mina::Dotenv::Utils.read_file(dotenv_location)
    queue! %(
      echo #{dotenv.shellescape} | sed -e 's/^[ \t]*//' > #{remote_dotenv_path}
    )
    queue! %(rm -f .env)
    queue! %(ln -nFs #{remote_dotenv_path} .env)
  end

  desc 'Copies the remote .env file to the current directory'
  task :pull do
    scp_download(remote_dotenv_path, dotenv_location)
    Mina::Dotenv::Utils.add_to_gitignore(dotenv_location)
  end

  desc 'Creates empty .env files, adds defaults to .gitignore and deploy.rb'
  task :init do
    add_default_to_gitignore
    add_to_deploy_script
    create_default_files
  end
end

def remote_dotenv_path
  "#{deploy_to}/#{shared_path}/.env"
end

def add_default_to_gitignore
  Mina::Dotenv::Utils.add_to_gitignore('!.env')
  Mina::Dotenv::Utils.add_to_gitignore('.env.*')
end

def add_to_deploy_script
  file = 'config/deploy.rb'
  line = 'require \'mina/dotenv\''
  Mina::Dotenv::Utils.prepend_to_file(file, line)
end

def create_default_files
  Mina::Dotenv::Utils.create_file('.env')
  Mina::Dotenv::Utils.create_file('.env.production')
end
